@@ -1,12 +1,11 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import fields
+from trytond.modules.analytic_account import AnalyticMixin
 from trytond.pool import Pool, PoolMeta
 from trytond.pyson import Eval
 from trytond.transaction import Transaction
 
-from trytond.modules.analytic_account import AnalyticMixin
-
 
 class Asset(AnalyticMixin, metaclass=PoolMeta):
     __name__ = 'account.asset'
@@ -17,7 +16,6 @@ class Asset(AnalyticMixin, metaclass=PoolMeta):
         cls.analytic_accounts.domain = [
             ('company', '=', Eval('company', -1)),
             ]
-        cls.analytic_accounts.depends.append('company')
 
     @fields.depends('supplier_invoice_line', 'analytic_accounts')
     def on_change_supplier_invoice_line(self):
@@ -59,3 +57,12 @@ class Asset(AnalyticMixin, metaclass=PoolMeta):
                         analytic_lines.extend(
                             entry.get_analytic_lines(line, move.date))
                     line.analytic_lines = analytic_lines
+
+
+class UpdateAsset(metaclass=PoolMeta):
+    __name__ = 'account.asset.update'
+
+    def get_move(self, asset):
+        move = super().get_move(asset)
+        asset.set_analytic_lines(move, self.show_move.counterpart_account)
+        return move
