@@ -1,32 +1,24 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import fields
-from trytond.pool import PoolMeta, Pool
-from trytond.pyson import Eval, If
-
 from trytond.modules.analytic_account import AnalyticMixin
-
-__all__ = ['InvoiceLine', 'AnalyticAccountEntry']
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Eval
 
 
-class InvoiceLine(AnalyticMixin):
-    __metaclass__ = PoolMeta
+class InvoiceLine(AnalyticMixin, metaclass=PoolMeta):
     __name__ = 'account.invoice.line'
 
     @classmethod
     def __setup__(cls):
         super(InvoiceLine, cls).__setup__()
         cls.analytic_accounts.domain = [
-            ('company', '=', If(~Eval('company'),
-                    Eval('context', {}).get('company', -1),
-                    Eval('company', -1))),
+            ('company', '=', Eval('company', -1)),
             ]
-        cls.analytic_accounts.depends.append('company')
         cls.analytic_accounts.states = {
             'invisible': Eval('type') != 'line',
             'readonly': Eval('invoice_state') != 'draft',
             }
-        cls.analytic_accounts.depends.extend(['type', 'invoice_state'])
 
     def _credit(self):
         pool = Pool()
@@ -61,8 +53,24 @@ class InvoiceLine(AnalyticMixin):
         return lines
 
 
-class AnalyticAccountEntry:
-    __metaclass__ = PoolMeta
+class InvoiceDeferred(metaclass=PoolMeta):
+    __name__ = 'account.invoice.deferred'
+
+    def get_move(self, period=None):
+        move = super().get_move(period=period)
+        if self.invoice_line.analytic_accounts:
+            for line in move.lines:
+                if line.account.type.statement != 'income':
+                    continue
+                analytic_lines = []
+                for entry in self.invoice_line.analytic_accounts:
+                    analytic_lines.extend(
+                        entry.get_analytic_lines(line, move.date))
+                line.analytic_lines = analytic_lines
+        return move
+
+
+class AnalyticAccountEntry(metaclass=PoolMeta):
     __name__ = 'analytic.account.entry'
 
     @classmethod
@@ -85,11 +93,10 @@ class AnalyticAccountEntry:
             Asset = pool.get('account.asset')
         except KeyError:
             Asset = None
-        company = super(AnalyticAccountEntry, self).on_change_with_company(
-            name)
+        company = super().on_change_with_company(name=name)
         if (isinstance(self.origin, InvoiceLine)
                 or (Asset and isinstance(self.origin, Asset))):
-            company = self.origin.company.id if self.origin.company else None
+            company = self.origin.company
         return company
 
     @classmethod
